=== modified file 'drizzled/drizzled.cc'
--- drizzled/drizzled.cc	2011-02-17 00:14:13 +0000
+++ drizzled/drizzled.cc	2011-02-15 20:03:56 +0000
@@ -308,8 +308,6 @@
 fs::path system_config_dir(SYSCONFDIR);
 
 
-DRIZZLED_API char glob_hostname[FN_REFLEN];
-
 char *opt_tc_log_file;
 const key_map key_map_empty(0);
 key_map key_map_full(0);                        // Will be initialized later
@@ -371,12 +369,12 @@
 
 fs::path base_plugin_dir(PKGPLUGINDIR);
 
-po::options_description config_options("Config File Options");
-po::options_description long_options("Kernel Options");
-po::options_description plugin_load_options("Plugin Loading Options");
-po::options_description plugin_options("Plugin Options");
-po::options_description initial_options("Config and Plugin Loading");
-po::options_description full_options("Kernel and Plugin Loading and Plugin");
+po::options_description config_options(_("Config File Options"));
+po::options_description long_options(_("Kernel Options"));
+po::options_description plugin_load_options(_("Plugin Loading Options"));
+po::options_description plugin_options(_("Plugin Options"));
+po::options_description initial_options(_("Config and Plugin Loading"));
+po::options_description full_options(_("Kernel and Plugin Loading and Plugin"));
 vector<string> unknown_options;
 vector<string> defaults_file_list;
 po::variables_map vm;
@@ -386,6 +384,25 @@
   return vm;
 }
 
+namespace
+{
+
+std::string &getGlobHostname()
+{
+  static std::string glob_hostname("localhost");
+  return glob_hostname;
+}
+
+void setServerHostname(const std::string &hostname)
+{
+  getGlobHostname()= hostname;
+}
+}
+
+const std::string &getServerHostname()
+{
+  return getGlobHostname();
+}
 
 /****************************************************************************
 ** Code to end drizzled
@@ -651,38 +668,18 @@
 
 static void find_plugin_dir(string progname)
 {
-  if (progname[0] != FN_LIBCHAR)
-  {
-    /* We have a relative path and need to find the absolute */
-    char working_dir[FN_REFLEN];
-    char *working_dir_ptr= working_dir;
-    working_dir_ptr= getcwd(working_dir_ptr, FN_REFLEN);
-    string new_path(working_dir);
-    if (*(new_path.end()-1) != '/')
-      new_path.push_back('/');
-    if (progname[0] == '.' && progname[1] == '/')
-      new_path.append(progname.substr(2));
-    else
-      new_path.append(progname);
-    progname.swap(new_path);
-  }
-
-  /* Now, trim off the exe name */
-  string progdir(progname.substr(0, progname.rfind(FN_LIBCHAR)+1));
-  if (progdir.rfind(".libs/") != string::npos)
-  {
-    progdir.assign(progdir.substr(0, progdir.rfind(".libs/")));
-  }
-  string testlofile(progdir);
-  testlofile.append("drizzled.lo");
-  string testofile(progdir);
-  testofile.append("drizzled.o");
-  struct stat testfile_stat;
-  if (not (stat(testlofile.c_str(), &testfile_stat) && stat(testofile.c_str(), &testfile_stat)))
+  fs::path full_progname(fs::system_complete(progname));
+
+  fs::path progdir(full_progname.parent_path());
+  if (progdir.filename() == ".libs")
+  {
+    progdir= progdir.parent_path();
+  }
+
+  if (fs::exists(progdir / "drizzled.lo") || fs::exists(progdir / "drizzled.o"))
   {
     /* We are in a source dir! Plugin dir is ../plugin/.libs */
-    size_t last_libchar_pos= progdir.rfind(FN_LIBCHAR,progdir.size()-2)+1;
-    base_plugin_dir= progdir.substr(0,last_libchar_pos);
+    base_plugin_dir= progdir.parent_path();
     base_plugin_dir /= "plugin";
     base_plugin_dir /= ".libs";
   }
@@ -1106,16 +1103,18 @@
   */
   global_system_variables.time_zone= my_tz_SYSTEM;
 
-  if (gethostname(glob_hostname,sizeof(glob_hostname)) < 0)
+  char ret_hostname[FN_REFLEN];
+  if (gethostname(ret_hostname,sizeof(ret_hostname)) < 0)
   {
-    strncpy(glob_hostname, STRING_WITH_LEN("localhost"));
-    errmsg_printf(error::WARN, _("gethostname failed, using '%s' as hostname"),
-                  glob_hostname);
+    errmsg_printf(error::WARN,
+                  _("gethostname failed, using '%s' as hostname"),
+                  getServerHostname().c_str());
     pid_file= "drizzle";
   }
   else
   {
-    pid_file= glob_hostname;
+    setServerHostname(ret_hostname);
+    pid_file= getServerHostname();
   }
   pid_file.replace_extension(".pid");
 

=== modified file 'drizzled/sys_var.cc'
--- drizzled/sys_var.cc	2011-02-17 00:14:13 +0000
+++ drizzled/sys_var.cc	2011-02-15 20:03:56 +0000
@@ -92,6 +92,12 @@
 
 extern TYPELIB tx_isolation_typelib;
 
+namespace
+{
+static size_t revno= DRIZZLE7_VC_REVNO;
+static size_t release_id= DRIZZLE7_RELEASE_ID;
+}
+
 const char *bool_type_names[]= { "OFF", "ON", NULL };
 TYPELIB bool_typelib=
 {
@@ -308,7 +314,12 @@
                                                   &drizzle_system_variables::group_concat_max_len);
 
 /* Global read-only variable containing hostname */
-static sys_var_const_str        sys_hostname("hostname", glob_hostname);
+static sys_var_const_string sys_hostname("hostname", getServerHostname());
+
+static sys_var_const_str sys_revid("vc_revid", DRIZZLE7_VC_REVID);
+static sys_var_const_str sys_branch("vc_branch", DRIZZLE7_VC_BRANCH);
+static sys_var_size_t_ptr_readonly sys_revno("vc_revno", &revno);
+static sys_var_size_t_ptr_readonly sys_release_id("vc_release_id", &release_id);
 
 bool sys_var::check(Session *session, set_var *var)
 {
@@ -1487,6 +1498,7 @@
     add_sys_var_to_list(&sys_back_log, my_long_options);
     add_sys_var_to_list(&sys_basedir, my_long_options);
     add_sys_var_to_list(&sys_big_selects, my_long_options);
+    add_sys_var_to_list(&sys_branch, my_long_options);
     add_sys_var_to_list(&sys_buffer_results, my_long_options);
     add_sys_var_to_list(&sys_bulk_insert_buff_size, my_long_options);
     add_sys_var_to_list(&sys_collation_server, my_long_options);
@@ -1521,7 +1533,10 @@
     add_sys_var_to_list(&sys_range_alloc_block_size, my_long_options);
     add_sys_var_to_list(&sys_read_buff_size, my_long_options);
     add_sys_var_to_list(&sys_read_rnd_buff_size, my_long_options);
+    add_sys_var_to_list(&sys_release_id, my_long_options);
     add_sys_var_to_list(&sys_replicate_query, my_long_options);
+    add_sys_var_to_list(&sys_revid, my_long_options);
+    add_sys_var_to_list(&sys_revno, my_long_options);
     add_sys_var_to_list(&sys_scheduler, my_long_options);
     add_sys_var_to_list(&sys_secure_file_priv, my_long_options);
     add_sys_var_to_list(&sys_select_limit, my_long_options);

=== modified file 'drizzled/sys_var.h'
--- drizzled/sys_var.h	2011-02-17 00:14:13 +0000
+++ drizzled/sys_var.h	2011-02-15 20:03:56 +0000
@@ -56,7 +56,6 @@
 extern const char *in_left_expr_name;
 extern const char *in_additional_cond;
 extern const char *in_having_cond;
-extern char glob_hostname[FN_REFLEN];
 extern boost::filesystem::path basedir;
 extern boost::filesystem::path pid_file;
 extern boost::filesystem::path secure_file_priv;
@@ -77,6 +76,7 @@
 
 uint64_t fix_unsigned(Session *, uint64_t, const struct option *);
 
+const std::string &getServerHostname();
 int sys_var_init();
 
 /**

=== modified file 'm4/pandora_canonical.m4'
--- m4/pandora_canonical.m4	2011-02-17 00:14:13 +0000
+++ m4/pandora_canonical.m4	2011-02-15 20:03:56 +0000
@@ -115,7 +115,7 @@
     vc_changelog=yes
   ])
   m4_if(PCT_VERSION_FROM_VC,yes,[
-    PANDORA_VC_VERSION
+    PANDORA_VC_INFO_HEADER
   ],[
     PANDORA_TEST_VC_DIR
 

=== modified file 'plugin/innobase/handler/ha_innodb.cc'
--- plugin/innobase/handler/ha_innodb.cc	2011-02-17 00:14:13 +0000
+++ plugin/innobase/handler/ha_innodb.cc	2011-02-15 20:03:56 +0000
@@ -1181,7 +1181,7 @@
           "Drizzle thread %"PRIu64", query id %"PRIu64", %s, %s, %s ",
           static_cast<uint64_t>(in_session->getSessionId()),
           static_cast<uint64_t>(in_session->getQueryId()),
-          glob_hostname,
+          getServerHostname().c_str(),
           user_identifier->address().c_str(),
           user_identifier->username().c_str()
   );

=== modified file 'plugin/logging_gearman/logging_gearman.cc'
--- plugin/logging_gearman/logging_gearman.cc	2011-02-17 00:14:13 +0000
+++ plugin/logging_gearman/logging_gearman.cc	2011-02-15 20:03:56 +0000
@@ -262,7 +262,7 @@
                session->tmp_table,
                session->total_warn_count,
                session->getServerId(),
-               drizzled::glob_hostname
+               drizzled::getServerHostname().c_str()
                );
   
     char job_handle[GEARMAN_JOB_HANDLE_SIZE];

=== modified file 'plugin/logging_query/logging_query.cc'
--- plugin/logging_query/logging_query.cc	2011-02-17 00:14:13 +0000
+++ plugin/logging_query/logging_query.cc	2011-02-15 20:03:56 +0000
@@ -277,7 +277,7 @@
               % session->tmp_table
               % session->total_warn_count
               % session->getServerId()
-              % glob_hostname;
+              % getServerHostname();
 
     string msgbuf= formatter.str();
 

